=======
History
=======

0.1.0 (2018-01-05)
------------------

* First release on PyPI.

0.2.0 (2018-04-11)
------------------

* Recipes were added in
* Custom Checkers
* Multiple master files can be used
* Module associated files to find master configs
* Detail finding in cli to get help on the fly

0.3.0 (2018-08-10)
------------------

* Added the ability require an config entry be a list
* Added significant unit tests

